"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const OrderBookWatcher_1 = require("./OrderBookWatcher");
const SnapshotRetriever_1 = require("./SnapshotRetriever");
const Updater_1 = require("./Updater");
const logger_1 = tslib_1.__importDefault(require("../util/logger"));
function createOrderBookWatcher(marketSelector, streamClient, restClient) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const market = yield restClient.getMarket(marketSelector);
        const restRetriever = new SnapshotRetriever_1.SnapshotRetriever({
            exchange: market.exchange.symbol,
            base: market.instrument.base.symbol,
            quote: market.instrument.quote.symbol
        }, restClient);
        const snapshotUpdater = new Updater_1.Updater(restRetriever);
        const watcher = new OrderBookWatcher_1.OrderBookWatcher(market.id, snapshotUpdater, streamClient);
        streamClient.onMarketUpdate((marketUpdate) => {
            if (marketUpdate.orderBookDelta)
                snapshotUpdater.applyDelta(marketUpdate.orderBookDelta);
        });
        watcher.onError((marketID, error) => {
            logger_1.default.error(`Error occurred with marketID: ${marketID}.\n`, error);
        });
        return watcher;
    });
}
exports.createOrderBookWatcher = createOrderBookWatcher;
//# sourceMappingURL=index.js.map